==> xsns_1.0.1.zip: xsns_1.0.1/xoops_trust_path/modules/xsns/act/mypage/friend_listAction.php <==
<?php
class friend_listAction extends mypageAction
{
function dispatch(&$context)
{
	global $xoopsUser;
	$own_uid = is_object($xoopsUser) ? $xoopsUser->getVar('uid') : 0;
	
	$limit = 10;
	$start = $this->getIntRequest('s', APP_REQUEST_GET);
	if(!isset($start) || $start<0){
		$start = 0;
	}
	
	$uid = $this->getIntRequest('uid', APP_REQUEST_GET);
	if(!$uid){
		$uid = ($this->isXoopsUser()) ? $xoopsUser->getVar('uid') : -1;
	}
	
	$user_handler =& CM_UserHandler::getInstance();
	$user =& $user_handler->get($uid);
	if(!is_object($user)){
		redirect_header(APP_BASE_URL, 2, _NOPERM);
	}
	
	$is_own_page = ($own_uid == $uid)? true : false;
	
	$friend_list_temp =& $user->getFriendList($limit, $start);
	$friend_count = $user->getFriendCount();
	
	$pager = $this->getPageSelector(_CM_URL_MYPAGE_FRIEND.'&uid='.$uid, 
						$start, $limit, count($friend_list_temp), $user->getFriendCount());
	
	$i = 0;
	$friend_list = array();
	foreach($friend_list_temp as $friend){
		if($own_uid==$uid){
			$friend_user =& $user_handler->get($friend['uid']);
			if($friend_user->isFriend($own_uid)){
				$edit_menu = "<li><a href='"._CM_URL_MYPAGE."&".APP_ACTION_ARG."=intro_add&uid=".$friend['uid']."'>"._CM_TITLE_MYPAGE_INTRO."</a></li>";
			}
			else{
				$edit_menu = "";
			}
			$edit_menu = "<ul>".$edit_menu."<li><a href='"._CM_URL_MYPAGE."&".APP_ACTION_ARG."=friend_del&uid=".$friend['uid']."'>"._CM_FRIEND_DELETE."</a></li></ul>";
		}
		else{
			$edit_menu = "";
		}
		
		$friend_list[$i] = $friend;
		$friend_list[$i]['edit_menu'] = $edit_menu;
		$i++;
	}
	
	$context->setAttributes('user_name', $user->getVar('uname'));
	$context->setAttributes('friend_list', $friend_list);
	$context->setAttributes('pager', $pager);
	$context->setAttributes('is_own_page', $is_own_page);
	$context->setAttributes('user_menu', $user->getMyMenu());
}
}
?>

==> xsns_1.0.4.zip: xsns_1.0.4/xoops_trust_path/modules/xsns/act/mypage/friend_listAction.php <==
<?php
class friend_listAction extends mypageAction
{
function dispatch(&$context)
{
	global $xoopsUser;
	$own_uid = is_object($xoopsUser) ? $xoopsUser->getVar('uid') : 0;
	
	$limit = 10;
	$start = $this->getIntRequest('s', APP_REQUEST_GET);
	if(!isset($start) || $start<0){
		$start = 0;
	}
	
	$uid = $this->getIntRequest('uid', APP_REQUEST_GET);
	if(!$uid){
		$uid = ($this->isXoopsUser()) ? $xoopsUser->getVar('uid') : -1;
	}
	
	$user_handler =& CM_UserHandler::getInstance();
	$user =& $user_handler->get($uid);
	if(!is_object($user)){
		redirect_header(APP_BASE_URL, 2, _NOPERM);
	}
	
	$is_own_page = ($own_uid == $uid)? true : false;
	
	$friend_list_temp =& $user->getFriendList($limit, $start);
	$friend_count = $user->getFriendCount();
	
	$pager = $this->getPageSelector(_CM_URL_MYPAGE_FRIEND.'&uid='.$uid, 
						$start, $limit, count($friend_list_temp), $user->getFriendCount());
	
	$i = 0;
	$friend_list = array();
	foreach($friend_list_temp as $friend){
		if($own_uid==$uid){
			$friend_user =& $user_handler->get($friend['uid']);
			if(is_object($friend_user) && $friend_user->isFriend($own_uid)){
				$edit_menu = "<li><a href='"._CM_URL_MYPAGE."&".APP_ACTION_ARG."=intro_add&uid=".$friend['uid']."'>"._CM_TITLE_MYPAGE_INTRO."</a></li>";
			}
			else{
				$edit_menu = "";
			}
			$edit_menu = "<ul>".$edit_menu."<li><a href='"._CM_URL_MYPAGE."&".APP_ACTION_ARG."=friend_del&uid=".$friend['uid']."'>"._CM_FRIEND_DELETE."</a></li></ul>";
		}
		else{
			$edit_menu = "";
		}
		
		$friend_list[$i] = $friend;
		$friend_list[$i]['edit_menu'] = $edit_menu;
		$i++;
	}
	
	$context->setAttributes('user_name', $user->getVar('uname'));
	$context->setAttributes('friend_list', $friend_list);
	$context->setAttributes('pager', $pager);
	$context->setAttributes('is_own_page', $is_own_page);
	$context->setAttributes('user_menu', $user->getMyMenu());
}
}
?>
